@@ -33,6 +33,9 @@ public class TwoWordCombineToRightAlg extends TemplateMatchingAlg
 {
     protected void applyTo(FeatureNode node, RelexContext context)
     {
+    	if (getTemplate().match(node) == null)
+    		return;
+    	
         FeatureNode leftNode = LinkView.getLeft(node);
         FeatureNode rightNode = LinkView.getRight(node);
 
@@ -58,8 +61,8 @@ public class TwoWordCombineToRightAlg extends TemplateMatchingAlg
         rightNode.set("collocation_end", leftNode);
         rightNode.set("collocation_start", rightNode);
    
-        //erase the other word strings
-        leftNode.set("str", null);
+        // Erase the other word strings
+        leftNode.set("str", new FeatureNode(""));
         // leftNode.set("orig_str", null);
         
         // System.out.println("RIGHT NODE SET TO " + str);
