@@ -20,6 +20,7 @@ package relex.algs;
  * This algorithm combines sequences of words which should be a single word 
  * (proper names, and idioms like "at hand")
  */
+import java.util.Map;
 import java.util.regex.Pattern;
 
 import relex.concurrent.RelexContext;
@@ -103,7 +104,11 @@ public class WordSequenceCombineAlg extends TemplateMatchingAlg
 
 	protected void applyTo(FeatureNode node, RelexContext context)
 	{
-		FeatureNode rightNode = getTemplate().val("right");
+		Map<String, FeatureNode> vars = getTemplate().match(node); 
+		if (vars == null)
+			return;
+		FeatureNode rightNode = getTemplate().val("right", vars);
+		
 		if (rightNode != LinkView.getRight(node))
 			throw new RuntimeException("variable 'right' is not properly assigned");
 		if (!isRightMost(rightNode, allLabelRegex))
@@ -112,13 +117,14 @@ public class WordSequenceCombineAlg extends TemplateMatchingAlg
 		FeatureNode leftNode = getLeftMost(rightNode, allLabelRegex);
 
 		String bigName = collectNames(leftNode, rightNode, allLabelRegex, true);
-		rightNode.get("ref").set("name", new FeatureNode(bigName));
+		FeatureNode bigNameF = new FeatureNode(bigName);
+		rightNode.get("ref").set("name", bigNameF);
 		
 		// See email message "Relex fixes: definites and conjoined 
 		// prepositions" from Mike Ross
 		// rightNode.get("ref").set("specific", new FeatureNode("T"));
 		
-		rightNode.set("str", new FeatureNode(bigName)); // bigNameWithSpaces));
+		rightNode.set("str", bigNameF);
 
 		// Set original string too, since the big name is created using original
 		// strings (if possible) -- err, no, we really need the original
@@ -127,15 +133,25 @@ public class WordSequenceCombineAlg extends TemplateMatchingAlg
 		// rightNode.set("orig_str", new FeatureNode(bigNameWithSpaces));
 		rightNode.set("collocation_end", rightNode);
 		rightNode.set("collocation_start", leftNode);
-		rightNode.set("start_char", leftNode.get("start_char"));
+		rightNode.get("start_char").setValue(leftNode.get("start_char").getValue());
 
 		// Use morphology on the right node, just in case.
-		// ??? Really ??? the combined thing will have underscores ... 
-		// Does wordnet really have morphology for these things?
-		// Shouldn't we have done morphology earlier, and not now?
-		FeatureNode orig = rightNode.get("orig_str");
-		MorphyAlg m = new MorphyAlg();
-		m.applyTo(rightNode, context);
-		rightNode.set("orig_str", orig);
+		// Err .. maybe not. What does this acheive?
+		//
+		// The combined string will have underscores in it, and that's OK.
+		// WordNet does contain underscored entities in it, so it does
+		// make sense to look these up, in principle. On the other hand,
+		// these combined strings are either entities (place names like
+		// "New York") or idioms ("en masse") and so finding the lemma
+		// for such things just doesn't really make sense. Worse, the
+		// Morphy algs does damage: it will take a corectly capitalized
+		// "New York" and turn it into the mis-capitalized "New york".
+		// So we're not going to do this, at least, not without a good
+		// explanation.
+		//
+		// FeatureNode orig = rightNode.get("orig_str");
+		// MorphyAlg m = new MorphyAlg();
+		// m.applyTo(rightNode, context);
+		// rightNode.set("orig_str", orig);
 	}
 }
