@@ -1,4 +1,3 @@
-package relex.corpus;
 /*
  * Copyright 2008 Novamente LLC
  *
@@ -15,6 +14,8 @@ package relex.corpus;
  * limitations under the License.
  */
 
+package relex.corpus;
+
 import java.util.List;
 
 /**
@@ -34,74 +35,49 @@ import java.util.List;
  * complete sentence yet, by calling getNextSentence().  Calls
  * to each of these routines can be arbitrarily alternated, with
  * sentence fragments buffered up.
- *
- * This is a convenience wrapper around the opennlp toolkit;
- * it fixes some bugs encountered there, and provides a more
- * convenient interface.
- *
- * Refactored, expanded version of ord.disco.taca.SentenceAnnotator
- *
- * XXX known bugs:
- * fails to recognize exclamation mark as end of sentence, unless
- * it is preceeded by white space.
  */
 public interface DocSplitter
 {
-	String DEFAULT_ENGLISH_FILENAME =
-	        "data/sentence-detector/EnglishSD.bin.gz";
-
-  /**
-   * Sets up
-   * @param emf for example, data/sentence-detector/EnglishSD.bin.gz
-   * @see #DEFAULT_ENGLISH_FILENAME
-   */
-  void setEnglishModelFilename(String emf);
-
-  /**
-   * Gets the setting
-   * @return file path
-   */
-  String getEnglishModelFilename();
-
 	/**
-	 * Used to prevent overzelous sentence detectors which have recognizable idiosyncracies
-   * @param s ...
-   * @param start ...
-   * @param end ...
-   * @return false if break is unacceptable
-   */
-  boolean acceptableBreak(String s, int start, int end);
+	 * Used to prevent overzelous sentence detectors which have 
+	 * recognizable idiosyncracies
+	 * @param s ...
+	 * @param start ...
+	 * @param end ...
+	 * @return false if break is unacceptable
+	 */
+	boolean acceptableBreak(String s, int start, int end);
 
 	/**
 	 * Adds more text to the buffer.
 	 * This allows this class to be used in FIFO mode: text is added with
 	 * this call, and sentences are extracted with the getNextSentence() call.
-   * @param newText text to be added
-   */
-  void addText(String newText);
+	 * @param newText text to be added
+	 */
+	void addText(String newText);
 
 	/**
 	 * Clears out the sentence buffer.
 	 */
-  void clearBuffer();
+	void clearBuffer();
 
 	/**
 	 * Gets the next sentence out of the buffered text.
 	 * @return null if there are no complete sentences in the buffer.
 	 */
-  String getNextSentence();
-
-	/**
-	 * Splits a document text string into sentences.
-   * @param docText text to be split
-   * @return a list of sentence start and end-points
-   */
-  List<TextInterval> process(String docText);
+	String getNextSentence();
 
 	/**
 	 * Splits a document text string into sentences.
 	 * @param docText text to be split
-   * @return a list of sentence strings.
+	 * @return a list of sentence start and end-points
 	 */
-  List<String> split(String docText);
+	List<TextInterval> process(String docText);
+
+	/**
+	 * Splits a document text string into sentences.
+	 * @param docText text to be split
+	 * @return a list of sentence strings.
+	 */
+	List<String> split(String docText);
 }
